@@ -30,6 +30,7 @@
 #include <QKeyEvent>
 #include <QListWidget>
 #include <QProgressDialog>
+#include <QRegularExpression>
 #include <QScreen>
 #include <QStandardPaths>
 #include <QTemporaryFile>
@@ -43,6 +44,15 @@
 using namespace std::chrono_literals;
 extern const QString starting_home;
 
+namespace
+{
+// Matches kernel command line tokens that are isolated or separated by whitespace
+const QRegularExpression hushTokenRx(QStringLiteral(R"((^|\s+)hush(\s+|$))"));
+const QRegularExpression quietTokenRx(QStringLiteral(R"((^|\s+)quiet(\s+|$))"));
+const QRegularExpression splashTokenRx(QStringLiteral(R"((^|\s+)splash(\s+|$))"));
+const QRegularExpression noSplashTokenRx(QStringLiteral(R"((^|\s+)nosplash(\s+|$))"));
+} // namespace
+
 MainWindow::MainWindow(QWidget *parent)
     : QDialog(parent),
       ui(new Ui::MainWindow)
@@ -850,16 +860,18 @@ void MainWindow::processGrubTheme(const QString &line)
 void MainWindow::processKernelCommandLine(QString line)
 {
     const QString cmdline = line.remove("GRUB_CMDLINE_LINUX_DEFAULT=").remove(QRegularExpression("[\"']"));
-    ui->textKernel->setText(live && !installedMode ? kernelOptions : cmdline);
+    const QString effectiveCmdline = live && !installedMode ? kernelOptions : cmdline;
+    ui->textKernel->setText(effectiveCmdline);
 
-    bool hasHush = cmdline.contains("hush");
-    bool hasQuiet = cmdline.contains("quiet");
+    bool hasHush = effectiveCmdline.contains(hushTokenRx);
+    bool hasQuiet = effectiveCmdline.contains(quietTokenRx);
+    bool hasSplash = effectiveCmdline.contains(splashTokenRx) && !effectiveCmdline.contains(noSplashTokenRx);
 
     ui->radioDetailedMsg->setChecked(hasQuiet);
     ui->radioLimitedMsg->setChecked(hasHush);
     ui->radioVeryDetailedMsg->setChecked(!hasHush && !hasQuiet);
 
-    ui->checkBootsplash->setChecked(cmdline.contains("splash") && isInstalled(requiredPackages));
+    ui->checkBootsplash->setChecked(hasSplash && isInstalled(requiredPackages));
 }
 
 // Read kernel line and options from /proc/cmdline
@@ -1116,11 +1128,11 @@ void MainWindow::radioDetailedMsgToggled(bool checked)
         ui->pushApply->setEnabled(true);
 
         QString line = ui->textKernel->text();
-        if (!line.contains(QLatin1String("quiet"))) {
+        if (!line.contains(quietTokenRx)) {
             line.append(line.isEmpty() ? "quiet" : " quiet");
         }
 
-        line.remove(QRegularExpression("\\s*hush"));
+        line.replace(hushTokenRx, " ");
         ui->textKernel->setText(line.trimmed());
     }
 }
@@ -1132,7 +1144,8 @@ void MainWindow::radioVeryDetailedMsgToggled(bool checked)
         ui->pushApply->setEnabled(true);
 
         QString line = ui->textKernel->text();
-        line.remove(QRegularExpression("\\s*quiet|\\s*hush"));
+        line.replace(hushTokenRx, " ");
+        line.replace(quietTokenRx, " ");
         ui->textKernel->setText(line.trimmed());
     }
 }
@@ -1146,10 +1159,10 @@ void MainWindow::radioLimitedMsgToggled(bool checked)
         QString line = ui->textKernel->text();
         QStringList options;
 
-        if (!line.contains(QLatin1String("quiet"))) {
+        if (!line.contains(quietTokenRx)) {
             options << "quiet";
         }
-        if (!line.contains(QLatin1String("hush"))) {
+        if (!line.contains(hushTokenRx)) {
             options << "hush";
         }
 
@@ -1197,13 +1210,14 @@ void MainWindow::comboBootsplashToggled(bool checked)
     QString line = ui->textKernel->text();
     if (checked) {
         loadPlymouthThemes();
-        if (!line.contains(QLatin1String("splash"))) {
+        line.replace(noSplashTokenRx, " ");
+        if (!line.contains(splashTokenRx)) {
             line.append(line.isEmpty() ? "splash" : " splash");
         }
     } else {
         ui->comboTheme->clear();
         ui->pushPreview->setDisabled(true);
-        line.remove(QRegularExpression("\\s*splash"));
+        line.replace(splashTokenRx, " ");
     }
 
     ui->textKernel->setText(line.trimmed());
@@ -1215,8 +1229,10 @@ void MainWindow::pushLogClicked()
     // Determine base path based on chroot status
     QString location = chroot.isEmpty() ? QString() : tempDir.path();
 
+    bool hasHush = kernelOptions.contains(hushTokenRx);
+
     // Primary log location based on kernel options
-    location += kernelOptions.contains("hush") ? "/run/rc.log" : "/var/log/boot.log";
+    location += hasHush ? "/run/rc.log" : "/var/log/boot.log";
 
     // Fallback to alternate log location if primary doesn't exist
     if (!QFile::exists(location)) {
